@@ -108,11 +108,11 @@ anjuta_util_from_file_to_file (GInputStream *istream,
  * anjuta_util_copy_file:
  * @src: the file where copy
  * @dest: the path to copy the @src
- * @show_error: TRUE to show a dialog error
+ * @show_error: %TRUE to show a dialog error
  *
  * Copies @src to @dest and shows a dialog error in case is needed.
  *
- * Returns: TRUE if there was an error copying the file.
+ * Returns: %TRUE if there was an error copying the file.
  */
 gboolean
 anjuta_util_copy_file (const gchar * src, const gchar * dest, gboolean show_error)
@@ -838,13 +838,12 @@ has_valid_scheme (const char *uri)
 
 /**
  * anjuta_util_file_new_for_commandline_arg:
- *
  * @arg: URI or relative or absolute file path
  *
  * Create a new file corresponding to arg, unlike g_file_new_for_commandline_arg,
  * keeps symbolic links in path name.
  *
- * Returns: A new GFile object
+ * Returns: (transfer full): A new GFile object
  */
 GFile *
 anjuta_util_file_new_for_commandline_arg (const gchar *arg)
@@ -1124,9 +1123,9 @@ anjuta_util_user_shell (void)
  *
  * Retrieves the user's preferred terminal.
  *
- * Returns: A newly allocated strings list. The first argument is the terminal
- * program name. The following are the arguments needed to execute
- * a command. The list has to be freed with g_strfreev
+ * Returns: (transfer full): A newly allocated strings list. The first argument
+ * is the terminal program name. The following are the arguments needed to
+ * execute a command. The list has to be freed with g_strfreev
  */
 /* copied from deprecated gnome_execute_terminal in libgnome */
 gchar **
@@ -1337,6 +1336,15 @@ anjuta_util_jump_to_matching_brace (IAnjutaIterable *iter, gchar brace, gint lim
 	return FALSE;
 }
 
+/**
+ * anjuta_util_parse_args_from_string:
+ * @string: arguments
+ *
+ * Parse arguments from a string to a GList.
+ *
+ * Returns: (element-type utf8) (transfer full): A newly allocated GList of
+ * strings.
+ */
 GList*
 anjuta_util_parse_args_from_string (const gchar* string)
 {
@@ -1512,12 +1520,12 @@ gboolean anjuta_util_diff(const gchar* uri, const gchar* text)
  * anjuta_util_is_project_file:
  * @filename: the file name
  *
- * Return TRUE if the file is an anjuta project file. It is implemented by
+ * Return %TRUE if the file is an anjuta project file. It is implemented by
  * checking only the file extension. So it does not check the existence
  * of the file. But it is working on an URI if it does not containt a
  * fragment.
  *
- * Returns: TRUE if the file is a project file, else FALSE
+ * Returns: %TRUE if the file is a project file, else %FALSE
  */
 gboolean
 anjuta_util_is_project_file (const gchar *filename)
@@ -1530,12 +1538,12 @@ anjuta_util_is_project_file (const gchar *filename)
  * anjuta_util_is_template_file:
  * @filename: the file name
  *
- * Return TRUE if the file is an template project file. It is implemented by
+ * Return %TRUE if the file is an template project file. It is implemented by
  * checking only the file extension. So it does not check the existence
  * of the file. But it is working on an URI if it does not containt a
  * fragment.
  *
- * Returns: TRUE if the file is a template file, else FALSE
+ * Returns: %TRUE if the file is a template file, else %FALSE
  */
 gboolean
 anjuta_util_is_template_file (const gchar *filename)
@@ -1550,8 +1558,8 @@ anjuta_util_is_template_file (const gchar *filename)
  *
  * Return the mime type corresponding to a file infor object.
  *
- * Returns: The mime type as a newly allocated string that must be freed with
- * g_free() or %NULL if the mime type cannot be found.
+ * Returns: (transfer full) (allow-none): The mime type as a newly allocated
+ * string that must be freed with g_free() or %NULL if the mime type cannot be found.
  */
 gchar *
 anjuta_util_get_file_info_mime_type (GFileInfo *info)
@@ -1602,8 +1610,9 @@ anjuta_util_get_file_info_mime_type (GFileInfo *info)
  *
  * Check if a file exists and return its mime type.
  *
- * Returns: NULL if the corresponding file doesn't exist or the mime type as a newly
- * allocated string that must be freed with g_free().
+ * Returns: (transfer full) (allow-none): %NULL if the corresponding file doesn't
+ * exist or the mime type as a newly allocated string that must be freed with
+ * g_free().
  */
 gchar *
 anjuta_util_get_file_mime_type (GFile *file)
@@ -2040,7 +2049,7 @@ anjuta_util_replace_home_dir_with_tilde (const gchar *uri)
  *
  * Expand environment variables $(var_name) and tilde (~) in the input string.
  *
- * Returns: a newly-allocated string that must be freed with g_free().
+ * Returns: (transfer full): a newly-allocated string that must be freed with g_free().
  */
 gchar*
 anjuta_util_shell_expand (const gchar *string)
@@ -2355,10 +2364,10 @@ anjuta_util_convert_gfile_list_to_relative_path_list (GList *list,
 /**
  * anjuta_util_builder_new:
  * @filename: Builder file name to open
- * @error: Optional error object, if NULL display a dialog if the file is missing
+ * @error: Optional error object, if %NULL display a dialog if the file is missing
  *
  * Create a new GtkBuilder object and load the file in it. Display an error
- * if the file is missing. Use a dialog if error is NULL, just a warning
+ * if the file is missing. Use a dialog if error is %NULL, just a warning
  * if the error can be reported.
   *
  * Returns: The new GtkBuilder object
@@ -2402,13 +2411,13 @@ anjuta_util_builder_new (const gchar *filename, GError **error)
  * @builder: Builder object
  * @first_widget: Name of first widget to get
  * ...: Address to store the first widget pointer, followed optionally by
- *		more name/pointer pairs, followed by NULL
+ *		more name/pointer pairs, followed by %NULL
  *
  * Create a new GtkBuilder object and load the file in it. Display an error
- * if the file is missing. Use a dialog if error is NULL, just a warning
+ * if the file is missing. Use a dialog if error is %NULL, just a warning
  * if the error can be reported.
   *
- * Returns: TRUE is everything works as expected.
+ * Returns: %TRUE is everything works as expected.
  */
 gboolean
 anjuta_util_builder_get_objects (GtkBuilder *builder, const gchar *first_widget,...)
@@ -2490,7 +2499,7 @@ anjuta_util_get_user_mail()
  *
  * Clones the contents of source GPtrArray into a new allocated GPtrArray.
  *
- * Return a new allocated GPtrArray with strings g_strdup (), NULL on error.
+ * Return a new allocated GPtrArray with strings g_strdup (), %NULL on error.
  * The returned array has set g_free as GDestroyNotity function, so that user
  * should only care to g_ptr_array_unref () without freeing the strings.
  */
