@@ -268,7 +268,7 @@ dir_pattern_new (const gchar *pattern, gboolean reverse)
 			{
 				ptr++;
 			} while  (*ptr == '?');
-			g_string_append_printf (regex, "(.{%ld})", (long int) (ptr - next));
+			g_string_append_printf (regex, "(.{%ld})", ptr - next);
 		}
 		else if (*ptr == '\\')
 		{
@@ -906,6 +906,9 @@ find_not_loaded_node (gpointer key, gpointer value, gpointer user_data)
 static gboolean
 dir_project_is_loaded (DirProject *project)
 {
+	if (project->groups == NULL)
+		return FALSE;
+
 	return g_hash_table_find (project->groups, find_not_loaded_node, NULL) == NULL;
 }
 
