@@ -57,6 +57,8 @@
 #include "git-patch-series-pane.h"
 #include "git-apply-mailbox-pane.h"
 
+#define SETTINGS_SCHEMA "org.gnome.anjuta.plugins.git"
+
 AnjutaCommandBarEntry branch_entries[] =
 {
 	{
@@ -203,6 +205,22 @@ AnjutaCommandBarEntry status_entries[] =
 		N_("Mark selected conflicted files as resolved"),
 		GTK_STOCK_PREFERENCES,
 		G_CALLBACK (on_resolve_conflicts_button_clicked)
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_FRAME,
+		NULL,
+		N_("Stash"),
+		NULL,
+		NULL,
+		NULL
+	},
+	{
+		ANJUTA_COMMAND_BAR_ENTRY_BUTTON,
+		"StashChanges",
+		N_("Stash uncommitted changes"),
+		N_("Save uncommitted changes without committing them"),
+		GTK_STOCK_SAVE,
+		G_CALLBACK (on_stash_changes_button_clicked)
 	}
 };
 
@@ -649,81 +667,59 @@ git_register_stock_icons (AnjutaPlugin *plugin)
 }
 
 static void
-on_dock_window_mapped (GtkWidget *dock_window, Git *plugin)
+on_git_tasks_button_toggled (GtkToggleButton *button, GtkWidget *dock)
 {
-	anjuta_shell_present_widget (ANJUTA_PLUGIN (plugin)->shell,
-	                             plugin->command_bar_window, NULL);
-}
-
-static void
-on_dock_window_unmapped (GtkWidget *dock_window, Git *plugin)
-{
-	anjuta_shell_hide_dockable_widget (ANJUTA_PLUGIN (plugin)->shell,
-	                                   plugin->command_bar_window, NULL);
+	gtk_widget_set_visible (dock, gtk_toggle_button_get_active (button));
 }
 
 static gboolean
 git_activate_plugin (AnjutaPlugin *plugin)
 {
 	Git *git_plugin;
-	GtkWidget *command_bar_viewport;
-	GtkWidget *dock_viewport;
+	GtkBuilder *builder;
+	gchar *objects[] = {"grip_box",
+						NULL};
+	GtkWidget *git_tasks_button;
 	
 	DEBUG_PRINT ("%s", "Git: Activating Git plugin …");
 	
 	git_plugin = ANJUTA_PLUGIN_GIT (plugin);
 
 	git_register_stock_icons (plugin);
+
+	builder = gtk_builder_new ();
+	gtk_builder_add_objects_from_file (builder, BUILDER_FILE, objects, NULL);
 	
 	/* Command bar and dock */
 	git_plugin->command_bar = anjuta_command_bar_new ();
 	git_plugin->dock = anjuta_dock_new ();
-	command_bar_viewport = gtk_viewport_new (NULL, NULL);
-	dock_viewport = gtk_viewport_new (NULL, NULL);
-	git_plugin->command_bar_window = gtk_scrolled_window_new (NULL, NULL);
-	git_plugin->dock_window = gtk_scrolled_window_new (NULL, NULL);
 
-	gtk_container_add (GTK_CONTAINER (command_bar_viewport), 
-	                   git_plugin->command_bar);
-	gtk_container_add (GTK_CONTAINER (dock_viewport), git_plugin->dock);
-	gtk_container_add (GTK_CONTAINER (git_plugin->command_bar_window), 
-	                   command_bar_viewport);
-	gtk_container_add (GTK_CONTAINER (git_plugin->dock_window), dock_viewport);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (git_plugin->command_bar_window), 
-	                                GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (git_plugin->dock_window),
-	                                GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (git_plugin->command_bar_window),
-	                                     GTK_SHADOW_NONE);
-	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (git_plugin->dock_window),
-	                                     GTK_SHADOW_NONE);
-	gtk_viewport_set_shadow_type (GTK_VIEWPORT (command_bar_viewport), 
-	                              GTK_SHADOW_NONE);
-	gtk_viewport_set_shadow_type (GTK_VIEWPORT (dock_viewport), 
-	                              GTK_SHADOW_NONE);
+	git_plugin->box = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 2);
+	gtk_box_pack_start (GTK_BOX (git_plugin->box), git_plugin->dock, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (git_plugin->box), git_plugin->command_bar, FALSE, FALSE, 0);
 	
 
 	anjuta_dock_set_command_bar (ANJUTA_DOCK (git_plugin->dock), 
 	                             ANJUTA_COMMAND_BAR (git_plugin->command_bar));
 
-	gtk_widget_show_all (git_plugin->command_bar_window);
-	anjuta_shell_add_widget (plugin->shell, git_plugin->command_bar_window, 
-	                         "GitCommandBar", _("Git Tasks"), "git-tasks",
-	                         ANJUTA_SHELL_PLACEMENT_LEFT, NULL);
+	gtk_widget_show (git_plugin->box);
+	gtk_widget_show (git_plugin->dock);
+	anjuta_shell_add_widget_custom (plugin->shell, git_plugin->box, "GitDock", 
+	                     			_("Git"), "git-plugin", 
+	                                GTK_WIDGET (gtk_builder_get_object (builder, "grip_box")), 
+	                                ANJUTA_SHELL_PLACEMENT_CENTER,
+	                     			NULL);
+	git_tasks_button = GTK_WIDGET (gtk_builder_get_object (builder, 
+	                                                       "git_tasks_button"));
 
-	gtk_widget_show_all (git_plugin->dock_window);
-	anjuta_shell_add_widget (plugin->shell, git_plugin->dock_window, "GitDock", 
-	                         _("Git"), "git-plugin", ANJUTA_SHELL_PLACEMENT_CENTER,
-	                         NULL);
+	g_signal_connect (G_OBJECT (git_tasks_button), "toggled",
+	                  G_CALLBACK (on_git_tasks_button_toggled),
+	                  git_plugin->command_bar);
 
-	g_signal_connect (G_OBJECT (git_plugin->dock_window), "map",
-	                  G_CALLBACK (on_dock_window_mapped),
-	                  git_plugin);
-
-	g_signal_connect (G_OBJECT (git_plugin->dock_window), "unmap",
-	                  G_CALLBACK (on_dock_window_unmapped),
-	                  git_plugin);
+	g_settings_bind (git_plugin->settings, "show-command-bar", 
+	                 git_tasks_button, "active", G_SETTINGS_BIND_DEFAULT);
 
+	
 	/* Create the branch list commands. There are two commands because some 
 	 * views need to be able to tell the difference between local and 
 	 * remote branches */
@@ -856,16 +852,7 @@ git_deactivate_plugin (AnjutaPlugin *plugin)
 	anjuta_plugin_remove_watch (plugin, git_plugin->editor_watch_id,
 								TRUE);
 
-	g_signal_handlers_disconnect_by_func (G_OBJECT (git_plugin->dock_window),
-	                                      G_CALLBACK (on_dock_window_mapped),
-	                                      plugin);
-
-	g_signal_handlers_disconnect_by_func (G_OBJECT (git_plugin->dock_window),
-	                                      G_CALLBACK (on_dock_window_unmapped),
-	                                      plugin);
-
-	anjuta_shell_remove_widget (plugin->shell, git_plugin->command_bar_window, NULL);
-	anjuta_shell_remove_widget (plugin->shell, git_plugin->dock_window, NULL);
+	anjuta_shell_remove_widget (plugin->shell, git_plugin->box, NULL);
 
 	g_object_unref (git_plugin->local_branch_list_command);
 	g_object_unref (git_plugin->remote_branch_list_command);
@@ -897,7 +884,16 @@ git_finalize (GObject *obj)
 static void
 git_dispose (GObject *obj)
 {
-	/* Disposition codes */
+	Git *git_plugin;
+
+	git_plugin = ANJUTA_PLUGIN_GIT (obj);
+
+	if (git_plugin->settings)
+	{
+		g_clear_object (&git_plugin->settings);
+		git_plugin->settings = NULL;
+	}
+	
 	G_OBJECT_CLASS (parent_class)->dispose (obj);
 }
 
@@ -907,6 +903,8 @@ git_instance_init (GObject *obj)
 	Git *plugin = ANJUTA_PLUGIN_GIT (obj);
 
 	plugin->command_queue = anjuta_command_queue_new (ANJUTA_COMMAND_QUEUE_EXECUTE_AUTOMATIC);
+	plugin->settings = g_settings_new (SETTINGS_SCHEMA);
+
 }
 
 static void
