@@ -1177,8 +1177,8 @@ static void ieditor_goto_position(IAnjutaEditor *editor, IAnjutaIterable* icell,
 	Sourceview* sv = ANJUTA_SOURCEVIEW(editor);
 	sourceview_cell_get_iter (cell, &iter);
 	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (sv->priv->document), &iter);
-	gtk_text_view_scroll_to_iter (GTK_TEXT_VIEW (sv->priv->view),
-								  &iter, 0, FALSE, 0, 0);
+	gtk_text_view_scroll_mark_onscreen (GTK_TEXT_VIEW (sv->priv->view),
+	                                    gtk_text_buffer_get_insert (sv->priv->document));
 }
 
 /* Return a newly allocated pointer containing the whole text */
@@ -2355,15 +2355,6 @@ iassist_proposals(IAnjutaEditorAssist* iassist,
                   gboolean finished,
                   GError** e)
 {
-	/* Hide if the only suggetions is exactly the typed word */
-	if (pre_word && proposals && g_list_length (proposals) == 1)
-	{
-		IAnjutaEditorAssistProposal* proposal = proposals->data;
-		AnjutaLanguageProposalData* data = proposal->data;
-		if (g_str_equal (pre_word, data->name))
-			proposals = NULL;
-	}
-	
 	Sourceview* sv = ANJUTA_SOURCEVIEW(iassist);
 	GtkSourceCompletion* completion = gtk_source_view_get_completion(GTK_SOURCE_VIEW(sv->priv->view));
 	GList* node;
