@@ -1406,8 +1406,8 @@ do_check_offline_files_changed (SymbolDBPlugin *sdb_plugin)
 		
 		if (db_path)
 			g_hash_table_replace (prj_elements_hash,
-			                      db_path,
-			                      filename);
+			                      (gchar *)db_path,
+			                      (gchar *)filename);
 		g_object_unref (gfile);
 	}	
 
@@ -1622,12 +1622,10 @@ static void
 on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 					const GValue *value, gpointer user_data)
 {
-	IAnjutaProjectManager *pm;
 	SymbolDBPlugin *sdb_plugin;
 	const gchar *root_uri;
 	gchar *root_dir;
 	GFile *gfile;
-	IAnjutaProject *project;
 	
 	sdb_plugin = ANJUTA_PLUGIN_SYMBOL_DB (plugin);
 
@@ -1661,9 +1659,6 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 	 * if the preferences says not to automatically scan the packages.
 	 */
 	gtk_widget_hide (sdb_plugin->progress_bar_system);
-	
-	pm = anjuta_shell_get_interface (ANJUTA_PLUGIN (sdb_plugin)->shell,
-									 IAnjutaProjectManager, NULL);
 
 
 	/*
@@ -1687,8 +1682,6 @@ on_project_root_added (AnjutaPlugin *plugin, const gchar *name,
 		
 	g_object_unref (gfile);
 
-	project = ianjuta_project_manager_get_current_project (pm, NULL);
-
 	/* let the project be something like "." to avoid problems when renaming the 
 	 * project dir */
 	sdb_plugin->project_opened = g_strdup (PROJECT_ROOT_NAME_DEFAULT);
@@ -2116,7 +2109,7 @@ symbol_db_activate (AnjutaPlugin *plugin)
 	sdb_plugin->dbv_notebook = gtk_notebook_new();
 	gtk_notebook_set_show_border (GTK_NOTEBOOK (sdb_plugin->dbv_notebook), FALSE);
 	gtk_notebook_set_show_tabs (GTK_NOTEBOOK (sdb_plugin->dbv_notebook), FALSE);
-	sdb_plugin->dbv_hbox = gtk_box_new (GTK_ORIENTATION_VERTICAL, 1);
+	sdb_plugin->dbv_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 1);
 
 	label = gtk_label_new (_("Symbols"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0f, 0.5f);
